Index: src/hydrogen.h |
diff --git a/src/hydrogen.h b/src/hydrogen.h |
index 19128065970ecfd4d391ba8bed35f98e6d8a3345..99e4f9c492b6d44b50046fa89d0966483e51dcae 100644 |
--- a/src/hydrogen.h |
+++ b/src/hydrogen.h |
@@ -1367,7 +1367,7 @@ class HGraphBuilder { |
HValue* capacity); |
// array must have been allocated with enough room for |
// 1) the JSArray, 2) a AllocationSiteInfo if mode requires it, |
// 3) a FixedArray or FixedDoubleArray. |
// A pointer to the Fixed(Double)Array is returned. |
HInnerAllocatedObject* BuildJSArrayHeader(HValue* array, |
@@ -1413,9 +1413,9 @@ class HGraphBuilder { |
int position, |
HIfContinuation* continuation); |
- HValue* BuildCreateAllocationSiteInfo(HValue* previous_object, |
- int previous_object_size, |
- HValue* payload); |
+ HValue* BuildCreateAllocationMemento(HValue* previous_object, |
+ int previous_object_size, |
+ HValue* payload); |
HInstruction* BuildGetNativeContext(HValue* context); |
HInstruction* BuildGetArrayFunction(HValue* context); |
@@ -1367,7 +1367,7 @@ class HGraphBuilder { |
HValue* capacity); |
// array must have been allocated with enough room for |
- // 1) the JSArray, 2) a AllocationSiteInfo if mode requires it, |
+ // 1) the JSArray, 2) a AllocationMemento if mode requires it, |
// 3) a FixedArray or FixedDoubleArray. |
// A pointer to the Fixed(Double)Array is returned. |